# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [2.0.12] - 2026-02-04

### Added
- Add flags for delete, create, update, query

## [2.0.11] - 2026-01-28

### Changed
- Bump version to v2.0.11 by @github-actions[bot]

### Fixed
- Ordering of modules

## [2.0.10] - 2026-01-28

### Changed
- Bump version to v2.0.10 by @github-actions[bot]

## [2.0.9] - 2026-01-28

### Added
- Add ordering

### Changed
- Bump version to v2.0.9 by @github-actions[bot]

## [2.0.8] - 2026-01-28

### Added
- Add support for just headings

### Changed
- Bump version to v2.0.8 by @github-actions[bot]

## [2.0.7] - 2026-01-28

### Added
- Add multi hierarchy

### Changed
- Bump version to v2.0.7 by @github-actions[bot]

## [2.0.6] - 2026-01-28

### Added
- Add some basic tests

### Changed
- Bump version to v2.0.6 by @github-actions[bot]
- Update to latest copier version
- Update dependencies

### Fixed
- Update to latest clear-skies QueryRequest

## [2.0.5] - 2025-10-16

### Changed
- Bump version to v2.0.5 by @github-actions[bot]
- Missing-f by @tnijboer in [#2](https://github.com/clearskies-py/doc-builder/pull/2)
- Missing-f by @cmancone
- Update copier
- Update copier

## [2.0.4] - 2025-09-03

### Added
- Add more folders to the build

### Changed
- Bump version to v2.0.4 by @github-actions[bot]

## [2.0.3] - 2025-09-03

### Changed
- Bump version to v2.0.3 by @github-actions[bot]

### Fixed
- Uv build

## [2.0.2] - 2025-09-03

### Changed
- Bump version to v2.0.2 by @github-actions[bot]

### Fixed
- Uv.lock
- Right reference to module for wheel

## [2.0.1] - 2025-09-03

### Added
- Add include_path for custom includes
- Add copier template

### Changed
- Bump version to v2.0.1 by @github-actions[bot]
- Merge pull request #1 from clearskies-py/copier by @tnijboer in [#1](https://github.com/clearskies-py/doc-builder/pull/1)
- Update for tooling by @cmancone
- WIP by @cmancone
- Initial commit by @cmancone

## New Contributors
* @github-actions[bot] made their first contribution
* @ made their first contribution
* @tnijboer made their first contribution in [#1](https://github.com/clearskies-py/doc-builder/pull/1)
* @cmancone made their first contribution
[2.0.12]: https://github.com/clearskies-py/doc-builder/compare/v2.0.11..v2.0.12
[2.0.11]: https://github.com/clearskies-py/doc-builder/compare/v2.0.10..v2.0.11
[2.0.10]: https://github.com/clearskies-py/doc-builder/compare/v2.0.9..v2.0.10
[2.0.9]: https://github.com/clearskies-py/doc-builder/compare/v2.0.8..v2.0.9
[2.0.8]: https://github.com/clearskies-py/doc-builder/compare/v2.0.7..v2.0.8
[2.0.7]: https://github.com/clearskies-py/doc-builder/compare/v2.0.6..v2.0.7
[2.0.6]: https://github.com/clearskies-py/doc-builder/compare/v2.0.5..v2.0.6
[2.0.5]: https://github.com/clearskies-py/doc-builder/compare/v2.0.4..v2.0.5
[2.0.4]: https://github.com/clearskies-py/doc-builder/compare/v2.0.3..v2.0.4
[2.0.3]: https://github.com/clearskies-py/doc-builder/compare/v2.0.2..v2.0.3
[2.0.2]: https://github.com/clearskies-py/doc-builder/compare/v2.0.1..v2.0.2

<!-- generated by git-cliff -->
